[cairo-commit] cairo/src cairo-glitz-surface.c, 1.63,
1.64 cairo-image-surface.c, 1.62, 1.63 cairo-pattern.c, 1.67,
1.68 cairo-xcb-surface.c, 1.48, 1.49 cairo-xlib-surface.c,
1.123, 1.124 cairo.h, 1.154, 1.155 cairoint.h, 1.213, 1.214
Billy Biggs
commit at pdx.freedesktop.org
Mon Oct 10 12:45:22 PDT 2005
Committed by: vektor
Update of /cvs/cairo/cairo/src
In directory gabe:/tmp/cvs-serv18114/src
Modified Files:
cairo-glitz-surface.c cairo-image-surface.c cairo-pattern.c
cairo-xcb-surface.c cairo-xlib-surface.c cairo.h cairoint.h
Log Message:
2005-10-10 Billy Biggs <vektor at dumbterm.net>
* src/cairo.h: Call it CAIRO_EXTEND_PAD instead of
CAIRO_EXTEND_NEAREST.
* src/cairoint.h:
* src/cairo-glitz-surface.c:
(_cairo_glitz_pattern_acquire_surface):
* src/cairo-image-surface.c (_cairo_image_surface_set_attributes):
* src/cairo-pattern.c (_cairo_pattern_calc_color_at_pixel):
* src/cairo-xcb-surface.c (_cairo_xcb_surface_set_attributes):
* src/cairo-xlib-surface.c (_cairo_xlib_surface_set_attributes):
Update everybody to use _PAD instead of _NEAREST.
Index: cairo-glitz-surface.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-glitz-surface.c,v
retrieving revision 1.63
retrieving revision 1.64
diff -u -d -r1.63 -r1.64
--- cairo-glitz-surface.c 9 Oct 2005 16:18:16 -0000 1.63
+++ cairo-glitz-surface.c 10 Oct 2005 19:45:15 -0000 1.64
@@ -682,7 +682,7 @@
case CAIRO_EXTEND_REFLECT:
attr->fill = GLITZ_FILL_REFLECT;
break;
- case CAIRO_EXTEND_NEAREST:
+ case CAIRO_EXTEND_PAD:
attr->fill = GLITZ_FILL_NEAREST;
break;
}
Index: cairo-image-surface.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-image-surface.c,v
retrieving revision 1.62
retrieving revision 1.63
diff -u -d -r1.62 -r1.63
--- cairo-image-surface.c 10 Oct 2005 03:31:45 -0000 1.62
+++ cairo-image-surface.c 10 Oct 2005 19:45:15 -0000 1.63
@@ -500,7 +500,7 @@
case CAIRO_EXTEND_REFLECT:
pixman_image_set_repeat (surface->pixman_image, PIXMAN_REPEAT_REFLECT);
break;
- case CAIRO_EXTEND_NEAREST:
+ case CAIRO_EXTEND_PAD:
pixman_image_set_repeat (surface->pixman_image, PIXMAN_REPEAT_PAD);
break;
}
Index: cairo-pattern.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-pattern.c,v
retrieving revision 1.67
retrieving revision 1.68
diff -u -d -r1.67 -r1.68
--- cairo-pattern.c 10 Oct 2005 16:16:21 -0000 1.67
+++ cairo-pattern.c 10 Oct 2005 19:45:15 -0000 1.68
@@ -955,7 +955,7 @@
factor -= factor & 0xffff0000;
}
break;
- case CAIRO_EXTEND_NEAREST:
+ case CAIRO_EXTEND_PAD:
case CAIRO_EXTEND_NONE:
break;
}
Index: cairo-xcb-surface.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-xcb-surface.c,v
retrieving revision 1.48
retrieving revision 1.49
diff -u -d -r1.48 -r1.49
--- cairo-xcb-surface.c 9 Oct 2005 16:18:16 -0000 1.48
+++ cairo-xcb-surface.c 10 Oct 2005 19:45:15 -0000 1.49
@@ -787,7 +787,7 @@
break;
case CAIRO_EXTEND_REFLECT:
return CAIRO_INT_STATUS_UNSUPPORTED;
- case CAIRO_EXTEND_NEAREST:
+ case CAIRO_EXTEND_PAD:
return CAIRO_INT_STATUS_UNSUPPORTED;
}
Index: cairo-xlib-surface.c
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo-xlib-surface.c,v
retrieving revision 1.123
retrieving revision 1.124
diff -u -d -r1.123 -r1.124
--- cairo-xlib-surface.c 9 Oct 2005 16:18:16 -0000 1.123
+++ cairo-xlib-surface.c 10 Oct 2005 19:45:15 -0000 1.124
@@ -937,7 +937,7 @@
_cairo_xlib_surface_set_repeat (surface, 1);
break;
case CAIRO_EXTEND_REFLECT:
- case CAIRO_EXTEND_NEAREST:
+ case CAIRO_EXTEND_PAD:
return CAIRO_INT_STATUS_UNSUPPORTED;
}
Index: cairoint.h
===================================================================
RCS file: /cvs/cairo/cairo/src/cairoint.h,v
retrieving revision 1.213
retrieving revision 1.214
diff -u -d -r1.213 -r1.214
--- cairoint.h 10 Oct 2005 03:31:45 -0000 1.213
+++ cairoint.h 10 Oct 2005 19:45:15 -0000 1.214
@@ -822,7 +822,7 @@
} cairo_stock_t;
#define CAIRO_EXTEND_SURFACE_DEFAULT CAIRO_EXTEND_NONE
-#define CAIRO_EXTEND_GRADIENT_DEFAULT CAIRO_EXTEND_NEAREST
+#define CAIRO_EXTEND_GRADIENT_DEFAULT CAIRO_EXTEND_PAD
#define CAIRO_FILTER_DEFAULT CAIRO_FILTER_BEST
typedef enum {
More information about the cairo-commit
mailing list
Index: cairo.h
===================================================================
RCS file: /cvs/cairo/cairo/src/cairo.h,v
retrieving revision 1.154
retrieving revision 1.155
diff -u -d -r1.154 -r1.155
--- cairo.h 10 Oct 2005 16:16:21 -0000 1.154
+++ cairo.h 10 Oct 2005 19:45:15 -0000 1.155
@@ -1296,7 +1296,7 @@
* @CAIRO_EXTEND_REPEAT: the pattern is tiled by repeating
* @CAIRO_EXTEND_REFLECT: the pattern is tiled by reflecting
* at the edges
* @CAIRO_EXTEND_NEAREST: pixels outside of the pattern copy
* the closest pixel from the source (since cairo 1.2)
*
* #cairo_extend_t is used to describe how the area outside
@@ -1306,7 +1306,7 @@
CAIRO_EXTEND_NONE,
CAIRO_EXTEND_REPEAT,
CAIRO_EXTEND_REFLECT,
- CAIRO_EXTEND_NEAREST
+ CAIRO_EXTEND_PAD
} cairo_extend_t;
cairo_public void
@@ -1296,7 +1296,7 @@
* @CAIRO_EXTEND_REFLECT: the pattern is tiled by reflecting
* at the edges
- * @CAIRO_EXTEND_NEAREST: pixels outside of the pattern copy
+ * @CAIRO_EXTEND_PAD: pixels outside of the pattern copy
* the closest pixel from the source (since cairo 1.2)
*